#!/bin/bash
DIR=`dirname $0`

case $2 in
p1) $DIR/../../../bin/genprog_tests.py --program grade $1 $DIR/../../tests/blackbox/9.out $DIR/../../tests/blackbox/9.in && exit 0;;
n1) $1 < $DIR/../../tests/blackbox/8.in &> out; diff out original-bbn1 || exit 0 ;; n2) $1 < $DIR/../../tests/blackbox/3.in &> out; diff out original-bbn2 || exit 0 ;; n3) $1 < $DIR/../../tests/blackbox/2.in &> out; diff out original-bbn3 || exit 0 ;; n4) $1 < $DIR/../../tests/blackbox/1.in &> out; diff out original-bbn4 || exit 0 ;; n5) $1 < $DIR/../../tests/blackbox/7.in &> out; diff out original-bbn5 || exit 0 ;; n6) $1 < $DIR/../../tests/blackbox/6.in &> out; diff out original-bbn6 || exit 0 ;; n7) $1 < $DIR/../../tests/blackbox/5.in &> out; diff out original-bbn7 || exit 0 ;; n8) $1 < $DIR/../../tests/blackbox/4.in &> out; diff out original-bbn8 || exit 0 ;; esac
exit 1
